/**
 * Copyright 2011 ISO NewEngland Inc.
 *
 * Caveat:
 * This example program is intended to serve only as working example of how to access eMarket MUI Webservices through Java and C# Clients.
 * It is not supported nor intended for production use.
 * Also, it is not intended to serve as a tool for end users.
 *
 * Furthermore, without modification, this example code will not work with eFTR, EES, OutageScheduler,
 * or the Settlements Market System. The example does not implement behavior critical to the interaction with the
 * aforementioned applications including: multi-part MIME, cookie handling, and capturing responses to a file.
 *
 * It is expected that a competent developer of moderate skill and knowledge of Java and/or C# and the HTTP protocol
 * would be able to use these examples as a guide for developing more sophisticated clients to interact
 * with the eMarket MUI WebServices.
 */

// For reading in properties
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import java.text.SimpleDateFormat;

import java.util.Properties;
import java.util.ArrayList;
import java.util.List;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.TimeZone;

// Security related classes
import java.security.KeyStore;
import javax.net.ssl.KeyManagerFactory;
import java.math.BigDecimal;
import javax.net.ssl.TrustManagerFactory;

// For marshaling to XML
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.XMLGregorianCalendar;
import javax.xml.datatype.DatatypeFactory;

//import wplp.windint.isone.alstom.com._1_0.wsdl;
// Classes generated from wsdl2java

import org.apache.cxf.configuration.jsse.TLSClientParameters;
import org.apache.cxf.frontend.ClientProxy;
import org.apache.cxf.interceptor.LoggingInInterceptor;
import org.apache.cxf.interceptor.LoggingOutInterceptor;
import org.apache.cxf.jaxws.JaxWsProxyFactoryBean;
import org.apache.cxf.transport.http.HTTPConduit;

/**
 * This sample program shows how to interact with eMarket Market User Interface
 * (MUI) using web services. The program relies on the having run the
 * eMktMUI.wsdl through the CXF wsdl2java. See the ant build file to see how
 * this is setup.
 */
public class Sample_Program {

	// -----------------------------------------------------------------
	// Configurable settings are driven from a properties file and held
	// in a local properties object.
	// -----------------------------------------------------------------

	private static String PROPERTIES_PATH = "./Sample_Program.properties";
	private static Properties properties;

	StringBuilder sb;
	String certLocation;
	long entityID;
	int testScheduleIDST;
	int testScheduleIDWPFA;
	final int resolution = 60;
	final int periodicity = 60;
	final int basetime = 0;
	final int fromforecasthorizon = 60;
	final int toforecasthorizon = 2880;
	static final int mvarating = 22;
	String status;
	String certName;
	wplp.windint.isone.alstom.com._1_0.wsdl.WindPlantLeadParticipantPortType windPlantLeadParticipantPortType;

	/**
	 * @param args
	 */
	public void initialize() {
		properties = getPropertiesFromFile(PROPERTIES_PATH);

		try {
			// Setup the proxy to the web service.
			windPlantLeadParticipantPortType = createWebServiceClient();
			windintegration.windint.isone.alstom.com._1_0.QueryEntitiesType queryEntitiesRequest = new windintegration.windint.isone.alstom.com._1_0.QueryEntitiesType();
			windintegration.windint.isone.alstom.com._1_0.QueryEntitiesResponseType queryEntitiesResponseType = windPlantLeadParticipantPortType
					.queryEntities(queryEntitiesRequest);
			ArrayList<windintegration.windint.isone.alstom.com._1_0.EntityIdentityType> EntityIdentityArrayTypeList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.EntityIdentityType>) queryEntitiesResponseType
					.getEntities().getEntity();

			// for each entity in response, look for BRKW and ISONE
			for (int i = 0; i < EntityIdentityArrayTypeList.size(); i++) {

				if (EntityIdentityArrayTypeList.get(i).getName().equals("STET")) {
					entityID = (int)Math.toIntExact(EntityIdentityArrayTypeList.get(i)
							.getIdentifier());
					System.out.println("Entity ID for STET : " + entityID);
				}

				if (EntityIdentityArrayTypeList.get(i).getName().equals("SPMT")) {
					entityID = (int) Math.toIntExact(EntityIdentityArrayTypeList.get(i)
							.getIdentifier());
					System.out.println("Entity ID for SPMT : " + entityID);
				}

			}

			windintegration.windint.isone.alstom.com._1_0.QuerySchedulesType querySchedulesType = new windintegration.windint.isone.alstom.com._1_0.QuerySchedulesType();
			windintegration.windint.isone.alstom.com._1_0.QuerySchedulesResponseType querySchedulesResponseType = windPlantLeadParticipantPortType
					.querySchedules(querySchedulesType);
			ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType> scheduleIdentityTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType>) querySchedulesResponseType
					.getSchedules().getSchedule();

			// for each entity in response, look for HRLYWPFA and ISONE
			for (int i = 0; i < scheduleIdentityTypeArrayList.size(); i++) {

				if (scheduleIdentityTypeArrayList.get(i).getName()
						.equals("HRLYWPFA-MW")) {
					testScheduleIDWPFA = (int) scheduleIdentityTypeArrayList
							.get(i).getIdentifier();
					System.out.println("HRLYWPFA-MW Schedule ID : "
							+ testScheduleIDWPFA);
				}

				if (scheduleIdentityTypeArrayList.get(i).getName()
						.equals("STWPFCST-MW")) {
					testScheduleIDST = (int) scheduleIdentityTypeArrayList.get(
							i).getIdentifier();
					System.out.println("STWPFCST-MW Schedule ID : "
							+ testScheduleIDST);
				}

			}

		} catch (Exception e) {
			System.err.println("\n*** Operation produced a Fault ***\n");
			e.printStackTrace();
		}

	}

	/**
	 * Create the CXF webservice Proxy.
	 *
	 * @return webService used throughout the project
	 */
	private static wplp.windint.isone.alstom.com._1_0.wsdl.WindPlantLeadParticipantPortType createWebServiceClient() {
		// factory for creating interface
		JaxWsProxyFactoryBean factory = new JaxWsProxyFactoryBean();

		// logging for in and out. Add these if you want more info spit out
		factory.getInInterceptors().add(new LoggingInInterceptor());
		factory.getOutInterceptors().add(new LoggingOutInterceptor());

		// add interface and end point
		factory.setServiceClass(wplp.windint.isone.alstom.com._1_0.wsdl.WindPlantLeadParticipantPortType.class);
		factory.setAddress(properties.getProperty("endpoint.link"));

		// instance of our web service message options
		wplp.windint.isone.alstom.com._1_0.wsdl.WindPlantLeadParticipantPortType webService = (wplp.windint.isone.alstom.com._1_0.wsdl.WindPlantLeadParticipantPortType) factory
				.create();

		// add certificate connectivity properties
		configureSSLOnTheClient(webService);

		return webService;
	}

	/**
	 * This method configures our transport layer to use <i>two way</i> secure
	 * HTTP To do this we're configuring the certificates we trust as well as
	 * the certificate that we are.
	 *
	 * @param c
	 *            - the CXF Proxy that we want to wrap with SSL
	 */
	private static void configureSSLOnTheClient(Object c) {
		// end point obtained
		org.apache.cxf.endpoint.Client client = ClientProxy.getClient(c);

		// conduit we're using to transfer data
		HTTPConduit httpConduit = (HTTPConduit) client.getConduit();

		try {
			// holds parameters for configuration
			TLSClientParameters tlsParams = new TLSClientParameters();
			//Do not set this to true in the Production Environment
			tlsParams.setDisableCNCheck(false);

			// format type for server side certificates
			KeyStore trustStore = KeyStore.getInstance(properties
					.getProperty("srvr.trust.fmt"));
			// location of server trusted list of certificates
			File serverTrusts = new File(
					properties.getProperty("srvr.trust.kstr"));

			// add trusted server certificates to store
			String propValue = properties.getProperty("srvr.trust.pswd");
			trustStore.load(new FileInputStream(serverTrusts),
					propValue.toCharArray());

			// trust manager generated
			TrustManagerFactory trustFactory = TrustManagerFactory
					.getInstance(TrustManagerFactory.getDefaultAlgorithm());// uses
			// default
			// Algorithm

			// initialize trust manager with the file acquired
			trustFactory.init(trustStore);

			// this configures our client to trust these certificates
			tlsParams.setTrustManagers(trustFactory.getTrustManagers());
			//tlsParams.setTrustManagers(null);

			// keys for client side
			KeyStore keyStore = KeyStore.getInstance(properties
					.getProperty("client.key.fmt"));

			// location of client key
			File clientKey = new File(properties.getProperty("client.key.file"));

			// load certificate file into key store using password

			propValue = properties.getProperty("client.key.pswd");

			keyStore.load(new FileInputStream(clientKey),
					propValue.toCharArray());

			// manager for keys
			KeyManagerFactory keyFactory = KeyManagerFactory
					.getInstance(KeyManagerFactory.getDefaultAlgorithm());// uses
			// default
			// Algorithm

			// authorize use of key
			propValue = properties.getProperty("client.key.pswd");
			keyFactory.init(keyStore, propValue.toCharArray());
			System.out.println("Security Configuration Completed!!!");
			// this sets our client to use the configured key and certificate as
			// our credentials
			tlsParams.setKeyManagers(keyFactory.getKeyManagers());

			// add parameters to conduit
			httpConduit.setTlsClientParameters(tlsParams);

			// exceptions are caught and dealt with the same way
		} catch (Exception e) {
			System.out
					.println("Security configuration failed with the following: ");
			e.printStackTrace();
			System.out.println("-------");
		}// end catch
	}// end

	/**
	 * Retrieves properties from a file for the use of this program.
	 *
	 * @param path
	 *            - a path to the properties file
	 * @return properties - the properties to be used
	 */
	private static Properties getPropertiesFromFile(String path) {
		Properties properties = new Properties();
		File file = new File(path);

		// attempt to read the file and absorb the properties contained within
		try {
			FileInputStream fileReader = new FileInputStream(file);
			properties.load(fileReader);
		} catch (FileNotFoundException e) {
			// print errors
			e.printStackTrace();
			System.exit(1);
		} catch (IOException e) {
			// print errors
			e.printStackTrace();
			System.exit(1);
		}

		return properties;
	}

	public boolean isInitialized() {
		return windPlantLeadParticipantPortType != null;
	}

	public void closeService() {
		if (windPlantLeadParticipantPortType != null) {
			windPlantLeadParticipantPortType = null;
		}
	}

	public static void main(String[] args) {
		Sample_Program sample_Program = new Sample_Program();
		sample_Program.initialize();
		sample_Program.queryCategories();
		sample_Program.queryEntities();
		sample_Program.querySchedules();
		sample_Program.submitWPFA();
	}

	public String queryCategories() {
		if (!isInitialized()) {
			initialize();
		}
		if (isInitialized()) {
			try {

				windintegration.windint.isone.alstom.com._1_0.QueryCategoriesType queryCategoriesType = new windintegration.windint.isone.alstom.com._1_0.QueryCategoriesType();

				windintegration.windint.isone.alstom.com._1_0.QueryCategoriesResponseType queryCategoriesResponseType = windPlantLeadParticipantPortType
						.queryCategories(queryCategoriesType);

				sb = new StringBuilder();
				sb.append("Results:" + "\n");
				windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType[] categoryIdentityTypeList = (windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType[]) ((ArrayList<windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType>) queryCategoriesResponseType
						.getCategories().getCategory()).toArray();
				System.out.println("Vinod" + categoryIdentityTypeList.length);

				for (int i = 0; i < categoryIdentityTypeList.length; i++) {
					sb.append(categoryIdentityTypeList[i].getIdentifier()
							+ " - " + categoryIdentityTypeList[i].getName()
							+ " - "
							+ categoryIdentityTypeList[i].getDescription()
							+ "\n");
				}

				status = sb.toString();
			} catch (Exception ex1) {
				ex1.printStackTrace();
			}
			return status;
		} else {
			return "Could not connect to server\n";
		}
	}

	public String queryEntities() {
		if (!isInitialized()) {
			initialize();
		}

		if (isInitialized()) {

			try {
				windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType categoryIdentityType = new windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType();
				categoryIdentityType.setIdentifier("WPLANT");

				windintegration.windint.isone.alstom.com._1_0.QueryEntitiesType queryEntitiesType = new windintegration.windint.isone.alstom.com._1_0.QueryEntitiesType();
				queryEntitiesType.setCategory(categoryIdentityType);

				windintegration.windint.isone.alstom.com._1_0.QueryEntitiesResponseType queryEntitiesResponseType = windPlantLeadParticipantPortType
						.queryEntities(queryEntitiesType);

				ArrayList<windintegration.windint.isone.alstom.com._1_0.EntityIdentityType> EntityIdentityArrayTypeList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.EntityIdentityType>) queryEntitiesResponseType
						.getEntities().getEntity();

				sb = new StringBuilder();
				sb.append("Results:" + "\n");

				for (int i = 0; i < EntityIdentityArrayTypeList.size(); i++) {
					sb.append(EntityIdentityArrayTypeList.get(i)
							.getIdentifier()
							+ " - "
							+ EntityIdentityArrayTypeList.get(i).getName()
							+ " - "
							+ EntityIdentityArrayTypeList.get(i)
									.getDescription() + "\n");
				}

			} catch (Exception ex1) {
				ex1.printStackTrace();
			}
			return sb.toString();
		} else {
			return "Could not connect to server\n";
		}
	}

	public String querySchedules() {

		if (!isInitialized()) {
			initialize();
		}

		if (isInitialized()) {

			try {
				windintegration.windint.isone.alstom.com._1_0.QuerySchedulesType querySchedulesType = new windintegration.windint.isone.alstom.com._1_0.QuerySchedulesType();

				windintegration.windint.isone.alstom.com._1_0.QuerySchedulesResponseType querySchedulesResponseType = windPlantLeadParticipantPortType
						.querySchedules(querySchedulesType);

				ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType> scheduleIdentityTypeArray = (ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType>) querySchedulesResponseType
						.getSchedules().getSchedule();

				sb = new StringBuilder();
				sb.append("Results:" + "\n");
				for (int i = 0; i < scheduleIdentityTypeArray.size(); i++) {
					sb.append(scheduleIdentityTypeArray.get(i).getIdentifier()
							+ " - "
							+ scheduleIdentityTypeArray.get(i).getName()
							+ " - "
							+ scheduleIdentityTypeArray.get(i).getDescription()
							+ "\n");
				}
			} catch (Exception ex1) {
				ex1.printStackTrace();
			}

			return sb.toString();
		} else {
			return "Could not connect to server\n";
		}
	}

	public String queryForecast() {

		if (!isInitialized()) {
			initialize();
		}

		if (isInitialized()) {

			try {
				windintegration.windint.isone.alstom.com._1_0.DateRangeType dateRangeType = new windintegration.windint.isone.alstom.com._1_0.DateRangeType();

				GregorianCalendar fromTimeGregorianCalendar = new GregorianCalendar();
				fromTimeGregorianCalendar.add(Calendar.MINUTE, -30);

				GregorianCalendar toTimeGregorianCalendar = new GregorianCalendar();
				toTimeGregorianCalendar.add(Calendar.HOUR_OF_DAY, 1);

				dateRangeType.setFromTime(DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(fromTimeGregorianCalendar));
				dateRangeType.setToTime(DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(toTimeGregorianCalendar));

				windintegration.windint.isone.alstom.com._1_0.EntityIdentityType entityIdentityType = new windintegration.windint.isone.alstom.com._1_0.EntityIdentityType();
				entityIdentityType.setIdentifier(new Integer(111).longValue());

				windintegration.windint.isone.alstom.com._1_0.EntitiesIdentityType entitiesIdentityType = new windintegration.windint.isone.alstom.com._1_0.EntitiesIdentityType();
				entitiesIdentityType.getEntity().add(entityIdentityType);

				windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType scheduleIdentityType = new windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType();

				scheduleIdentityType.setIdentifier(111);

				windintegration.windint.isone.alstom.com._1_0.BaseRequestType baseRequestType = new windintegration.windint.isone.alstom.com._1_0.BaseRequestType();
				baseRequestType.setSchedule(scheduleIdentityType);
				baseRequestType.setEntities(entitiesIdentityType);
				windintegration.windint.isone.alstom.com._1_0.ScheduleRequestType queryForecastType = new windintegration.windint.isone.alstom.com._1_0.ScheduleRequestType();

				ArrayList<windintegration.windint.isone.alstom.com._1_0.BaseRequestType> BaseRequestTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.BaseRequestType>) queryForecastType
						.getScheduleRequest();
				BaseRequestTypeArrayList.add(baseRequestType);

				windintegration.windint.isone.alstom.com._1_0.PowerScheduleResponseType queryForecastResponseType = windPlantLeadParticipantPortType
						.queryForecast(queryForecastType);

				sb = new StringBuilder();
				sb.append("Results:" + "\n");
				ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType> powerScheduleDataTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType>) queryForecastResponseType
						.getScheduleResponse();

				ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType> ScheduleIdentityTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType>) powerScheduleDataTypeArrayList
						.get(0).getSchedule();

				ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType> PowerEntityIdentityTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType>) powerScheduleDataTypeArrayList
						.get(0).getEntities().getEntity();

				sb.append(ScheduleIdentityTypeArrayList.get(0).getIdentifier()
						+ " - "
						+ ScheduleIdentityTypeArrayList.get(0).getName() + "\n");
				sb.append(powerScheduleDataTypeArrayList.get(0).getTimeRange()
						.getFromTime().toString()
						+ " -"
						+ powerScheduleDataTypeArrayList.get(0).getTimeRange()
								.getToTime().toString());

				int data = 0;
				for (int i = 0; i < PowerEntityIdentityTypeArrayList.size(); i++) {
					sb.append(PowerEntityIdentityTypeArrayList.get(i).getName()
							+ " - "
							+ PowerEntityIdentityTypeArrayList.get(i)
									.getIdentifier());

					if (PowerEntityIdentityTypeArrayList.get(i).getPower() != null) {
						ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> TimeValueSeriesTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType>) PowerEntityIdentityTypeArrayList
								.get(i).getPower();

						for (int j = 0; j < TimeValueSeriesTypeArrayList.size(); j++) {
							data++;
							SimpleDateFormat sf = new SimpleDateFormat(
									"yyyy-MM-dd HH:mm:ss");
							sf.setTimeZone(Calendar.getInstance().getTimeZone());

							sb.append(TimeValueSeriesTypeArrayList.get(j)
									.getValue()
									+ " -"
									+ TimeValueSeriesTypeArrayList.get(j)
											.getTime().toString());
						}
					}
				}
				if (data == 0) {
					sb.append("No Data Found");
				}

			} catch (Exception ex1) {
				ex1.printStackTrace();
			}
			return sb.toString();
		} else {
			return "Could not connect to server\n";
		}
	}

	/**
	 * This static method returns an Arraylist of TimeValueSeriesType for 48
	 * hours starting next hour.
	 *
	 * @return <b>ArrayList</b> of type
	 *         <b>windintegration.windint.isone.alstom.com
	 *         ._1_0.TimeValueSeriesType</b>
	 */
	public static ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> getTimeValueSeriesTypeForHourly() {

		GregorianCalendar gregorianCalendar = (GregorianCalendar) Calendar
				.getInstance(TimeZone.getTimeZone("UTC"));
		gregorianCalendar.set(Calendar.MINUTE, 0);
		gregorianCalendar.set(Calendar.SECOND, 0);
		ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> timeValueSeriesTypeArrayList = new ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType>();

		for (int i = 0; i < 48; i++) {
			windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType timeValueSeriesType = new windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType();
			gregorianCalendar.add(Calendar.HOUR_OF_DAY, 1);

			try {
				timeValueSeriesType.setTime(DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(gregorianCalendar));
			} catch (DatatypeConfigurationException e) {
				e.printStackTrace();
			}

			timeValueSeriesType.setValue(BigDecimal.valueOf(mvarating));
			timeValueSeriesTypeArrayList.add(timeValueSeriesType);
		}

		return timeValueSeriesTypeArrayList;

	}

	public ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> dataGenerator(
			int resolution, int periodicity, int basetime,
			int fromforecasthorizon, int toforecasthorizon) {
		ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> TimeValueSeriesTypeArrayList = new ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType>();
		try {
			windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType[] timeValueSeriesTypeArray = new windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType[((toforecasthorizon - fromforecasthorizon) / resolution) + 1];

			GregorianCalendar gregorianCalendar = (GregorianCalendar) Calendar
					.getInstance(TimeZone.getTimeZone("UTC"));

			// Round to next interval
			gregorianCalendar
					.add(Calendar.MINUTE,
							periodicity
									- ((gregorianCalendar.MINUTE + gregorianCalendar.HOUR * 60) % periodicity));
			gregorianCalendar.add(Calendar.MINUTE, basetime);
			gregorianCalendar.add(Calendar.SECOND, -gregorianCalendar.SECOND);
			GregorianCalendar gregorianCalendarFromTime = (GregorianCalendar) gregorianCalendar
					.clone();

			gregorianCalendarFromTime.add(Calendar.MINUTE, fromforecasthorizon);

			GregorianCalendar gregorianCalendarToTime = (GregorianCalendar) gregorianCalendar
					.clone();
			gregorianCalendarToTime.add(Calendar.MINUTE, toforecasthorizon);

			// Fill in TimeValueSeries
			for (int i = 0; gregorianCalendarFromTime.getTime().getTime() <= gregorianCalendarToTime
					.getTime().getTime(); i++) {
				windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType timeValueSeriesType = new windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType();
				gregorianCalendarFromTime.add(Calendar.MINUTE, (i * resolution)
						+ fromforecasthorizon);
				timeValueSeriesType.setTime(DatatypeFactory.newInstance()
						.newXMLGregorianCalendar(gregorianCalendarFromTime));
				BigDecimal bigDecimal = new BigDecimal(i % mvarating);
				timeValueSeriesType.setValue(bigDecimal);
				TimeValueSeriesTypeArrayList.add(timeValueSeriesType);
			}
		} catch (Exception exception) {
			exception.printStackTrace();
		}

		return TimeValueSeriesTypeArrayList;
	}

	public String submitWPFA() {
		if (!isInitialized()) {
			initialize();
		}

		if (isInitialized()) {
			try {
				windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType powerScheduleDataType = new windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType();
				windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType categoryIdentityType = new windintegration.windint.isone.alstom.com._1_0.CategoryIdentityType();
				categoryIdentityType.setIdentifier("WPLANT");
				ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType> scheduleIdentityTypeArray = (ArrayList<windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType>) powerScheduleDataType
						.getSchedule();
				windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType scheduleIdentityType = new windintegration.windint.isone.alstom.com._1_0.ScheduleIdentityType();
				scheduleIdentityType.setIdentifier(51059001);
				scheduleIdentityTypeArray.add(scheduleIdentityType);
				windintegration.windint.isone.alstom.com._1_0.PowerEntitiesIdentityType powerEntitiesIdentityType = new windintegration.windint.isone.alstom.com._1_0.PowerEntitiesIdentityType();
				windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType powerEntityIdentityType = new windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType();
				powerEntityIdentityType.setIdentifier(new Integer(10011).longValue());
				ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType> timeValueSeriesTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.TimeValueSeriesType>) powerEntityIdentityType
						.getPower();
				timeValueSeriesTypeArrayList
						.addAll(getTimeValueSeriesTypeForHourly());
				ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType> powerEntityIdentityTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerEntityIdentityType>) powerEntitiesIdentityType
						.getEntity();
				powerEntityIdentityTypeArrayList.add(powerEntityIdentityType);
				powerScheduleDataType.setCategory(categoryIdentityType);
				powerScheduleDataType.setEntities(powerEntitiesIdentityType);
				windintegration.windint.isone.alstom.com._1_0.CreatePowerScheduleType submitForecastRequest = new windintegration.windint.isone.alstom.com._1_0.CreatePowerScheduleType();
				ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType> powerScheduleDataTypeArrayList = (ArrayList<windintegration.windint.isone.alstom.com._1_0.PowerScheduleDataType>) submitForecastRequest
						.getCreateSchedule();
				powerScheduleDataTypeArrayList.add(powerScheduleDataType);
				windintegration.windint.isone.alstom.com._1_0.SubmitStatusResponseType response = windPlantLeadParticipantPortType
						.submitForecast(submitForecastRequest);
				sb = new StringBuilder();
				sb.append("start printing" + timeValueSeriesTypeArrayList);
				sb.append("Results:" + "\n");
				sb.append("Success!" + "\n");
				sb.append(response.getSubmitStatusResponse().getSuccess()
						.getTransactionId());
			} catch (Exception ex1) {
				ex1.printStackTrace();
			}
			return sb.toString();
		} else {
			return "Could not connect to server\n";
		}
	}

}// end class MUIClientSample
